/* =============================================================[ Display.hh ]=
 * Display.hh - display an interface
 * Copyright (C) 2002 Hubert Chan <hubert@uhoreg.ca>
 *
 * ----------------------------------------------------------------( License )-
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * ------------------------------------------------------------( Description )-
 *
 * This file handles the user interface display.  This is an abstract class.
 * Specific display types inherit from it.  It defines an interface for the
 * different components to notify it of changes.
 *
 * ------------------------------------------------------------------------- */

#ifndef __DISPLAY_HH_
#define __DISPLAY_HH_

#include <alsaplayer/Playlist.h>

#include "SessionData.hh"
#include "PlaylistInterface.hh"

class Display : public ModeSubscriber
{
public:
  Display(SessionData &);
  virtual ~Display();

protected:
  void notifier_init();

public:

  // core player notification
  virtual void volumeChanged(int vol) = 0;
  virtual void speedChanged(float speed) = 0;
  virtual void panChanged(int pan) = 0;
  virtual void positionNotify(int frame) = 0;
  virtual void playerStopped() = 0;
  virtual void playerStarted() = 0;

  // player controls
  virtual void playerPaused() = 0;
  virtual void playerUnpaused() = 0;

  // playlist management
  virtual void setCurrentSong(int pos) = 0;
  virtual void setSelectedSong(int pos) = 0;
  virtual void songsInserted(int pos) = 0;
  virtual void songUpdated(int pos) = 0;
  virtual void songsRemoved(int pos) = 0;
  virtual void playlistCleared() = 0;
  virtual void setPlaylistMode(playlistmode_t) = 0;

  // song selector
  virtual void setSelection(int pos) = 0;
  virtual void updateSelectionList() = 0;

  // preferences
  virtual void setPreference(int pos) = 0;
  virtual void updatePreference(int pos) = 0;
};

#endif //__DISPLAY_HH_
