/* ===================================================[ PlaylistInterface.hh ]=
 * PlaylistInterface.hh - interface with the AlsaPlayer playlist
 * Copyright (C) 2002 Hubert Chan <hubert@uhoreg.ca>
 *
 * ----------------------------------------------------------------( License )-
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * ------------------------------------------------------------( Description )-
 *
 * This file fetches, keeps track of, and modifies the AlsaPlayer playlist.
 *
 * ------------------------------------------------------------------------- */

#ifndef __PLAYLIST_INTERFACE_HH_
#define __PLAYLIST_INTERFACE_HH_

#include <vector>

#include <alsaplayer/Playlist.h>

#include "SessionData.hh"

class LIRC_PlaylistInterface : public PlaylistInterface
{
  SessionData &sessiondata;

  std::vector<PlayItem> playlist;

public:
  LIRC_PlaylistInterface(SessionData &);
  virtual ~LIRC_PlaylistInterface();

  // interface functions defined in alsaplayer/Playlist.h
  void CbSetCurrent(unsigned pos);
  void CbInsert(std::vector<PlayItem> &items, unsigned pos);
  void CbUpdated(PlayItem &item, unsigned pos);
  void CbRemove(unsigned, unsigned);
  void CbClear();

  // access operations
  int getSize() const { return playlist.size(); }
  const PlayItem &getItem(int i) const { return playlist[i]; }
};

#endif //__PLAYLIST_INTERFACE_HH_
