/* ============================================================[ Selector.hh ]=
 * Selector.hh - select an item from a list
 * Copyright (C) 2002 Hubert Chan <hubert@uhoreg.ca>
 *
 * ----------------------------------------------------------------( License )-
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * ------------------------------------------------------------( Description )-
 *
 * This file maintains a list and allows the user to select an item.  It also
 * allows the user to go down into sublists.  This is used for inserting songs
 * into the playlist.
 *
 * ------------------------------------------------------------------------- */

#ifndef __SELECTOR_HH_
#define __SELECTOR_HH_

#include <vector>
#include <string>
#include <stack>

#include <alsaplayer/Playlist.h>

class Selector
{
public:
  class ListGenerator;
  class ListItem
  {
    std::string name;

  public:
    ListItem(const std::string &_name) : name(_name) { }
    virtual ~ListItem() { }

    const std::string &getName() const { return name; }

    virtual ListGenerator *sublistGenerator() const { return NULL; }
    virtual void addToPlaylist(Playlist *playlist, int pos) const { }
  };

private:
  std::stack<ListGenerator*> history;
  std::vector<ListItem*> selectionList;

  void clear();
public:
  Selector();
  ~Selector();

  int getSize() const { return selectionList.size(); }
  const std::string &getItemName(int i) const { return selectionList[i]->getName(); }

  bool loadSublist(int selection);
  bool backout();
  void addToPlaylist(int selection, Playlist *playlist, int pos);
};

#endif //__SELECTOR_HH_
