/* ===============================================================[ debug.hh ]=
 * debug.hh - debugging functions
 * Copyright (C) 2003 Hubert Chan <hubert@uhoreg.ca>
 *
 * ----------------------------------------------------------------( License )-
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * ------------------------------------------------------------( Description )-
 *
 * This file provides debugging functions that are turned on or off at compile
 * time.  There are four levels of debugging, from off to lots, set by
 * defining the DEBUG macro to the level (0 to 3).
 *
 * ------------------------------------------------------------------------- */

#ifndef __DEBUG_HH_
#define __DEBUG_HH_

namespace {
  class NullStream
  {
  } nullstream;

  template <class Cls>
  inline NullStream &operator<<(NullStream &ns, const Cls &foo)
  { return ns; }
}

#if defined DEBUG && DEBUG > 0
#  include <iostream>
#  include <cassert>
#  define DEBUG1 std::cerr
#  define ASSERT1(x) assert(x)
#else // DEBUG == 0
#  define DEBUG1 nullstream
#  define ASSERT1(x)
#endif // DEBUG > 0

#if defined DEBUG && DEBUG > 1
#  include <iostream>
#  define DEBUG2 std::cerr
#  define ASSERT2(x) assert(x)
#else // DEBUG <= 1
#  define DEBUG2 nullstream
#  define ASSERT2(x)
#endif // DEBUG > 1

#if defined DEBUG && DEBUG > 2
#  include <iostream>
#  define DEBUG3 std::cerr
#  define ASSERT3(x) assert(x)
#else // DEBUG <= 2
#  define DEBUG3 nullstream
#  define ASSERT3(x)
#endif // DEBUG > 2

#endif //__DEBUG_HH_
